pub enum DrawPhase {
Opaque = 0,
Background = 1,
Transparent = 2,
PickingLayer = 3,
OutlineMask = 4,
OutlineMaskNoDepth = 5,
Compositing = 6,
CompositingScreenshot = 7,
}Expand description
Determines a (very rough) order of rendering and describes the active wgpu::RenderPass.
Currently we do not support sorting within a rendering phase!
See #702
Within a phase DrawData are drawn in the order they are submitted in.
TODO(andreas): Should every phase/processor be associated with a single wgpu::RenderPass?
Note that this implies sub-phases (e.g. Opaque & background render to the same target).
Also we should then the higher level one to RenderPass or similar!
Variants
Opaque = 0
Opaque objects, performing reads/writes to the depth buffer.
Typically they are order independent, so everything uses this same index.
Background = 1
Background, rendering where depth wasn’t written.
Transparent = 2
Transparent objects, performing reads of the depth buffer, but no writes.
PickingLayer = 3
Everything that can be picked with GPU based picking.
Typically this contains everything from both the Opaque and Transparent phases drawn with z-test enabled.
OutlineMask = 4
Render mask for things that should get outlines.
OutlineMaskNoDepth = 5
Outline masks for special cases that should follow draw order
instead of the regular DrawPhase::OutlineMask pass depth buffer.
For example outlines for coplanar geometries that would otherwise have z-fighting.
Compositing = 6
Drawn when compositing with the main target.
CompositingScreenshot = 7
Drawn when compositing with the main target, but for screenshots. This is a separate phase primarily because screenshots may be rendered with a different texture format.