pub struct GaussianSplatDrawData { /* private fields */ }Expand description
A gaussian splat drawing operation. Expected to be recreated every frame.
Implementations
Sourceimpl GaussianSplatDrawData
impl GaussianSplatDrawData
Sourcepub fn new(
builder: GaussianSplatBuilder<'_>,
) -> Result<Self, GaussianSplatDrawDataError>
pub fn new( builder: GaussianSplatBuilder<'_>, ) -> Result<Self, GaussianSplatDrawDataError>
Transforms and uploads gaussian data to be consumed by the GPU.
Try to bundle all gaussians into a single draw data instance whenever possible.