pub struct PointCloudDrawData { /* private fields */ }Expand description
A point cloud drawing operation. Expected to be recreated every frame.
Implementations
Sourceimpl PointCloudDrawData
impl PointCloudDrawData
Sourcepub fn new(
builder: PointCloudBuilder<'_>,
) -> Result<Self, PointCloudDrawDataError>
pub fn new( builder: PointCloudBuilder<'_>, ) -> Result<Self, PointCloudDrawDataError>
Transforms and uploads point cloud data to be consumed by gpu.
Try to bundle all points into a single draw data instance whenever possible. Number of vertices and colors has to be equal.
If no batches are passed, all points are assumed to be in a single batch with identity transform.