pub struct BindGroupDesc {
pub label: Label,
pub entries: SmallVec<[BindGroupEntry; 4]>,
pub layout: GpuBindGroupLayoutHandle,
}Fields
label: LabelDebug label of the bind group. This will show up in graphics debuggers for easy identification.
entries: SmallVec<[BindGroupEntry; 4]>layout: GpuBindGroupLayoutHandleTrait Implementations
Sourceimpl Clone for BindGroupDesc
impl Clone for BindGroupDesc
Sourcefn clone(&self) -> BindGroupDesc
fn clone(&self) -> BindGroupDesc
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BindGroupDesc
impl Debug for BindGroupDesc
Sourceimpl Hash for BindGroupDesc
impl Hash for BindGroupDesc
Sourceimpl PartialEq for BindGroupDesc
impl PartialEq for BindGroupDesc
Sourcefn eq(&self, other: &BindGroupDesc) -> bool
fn eq(&self, other: &BindGroupDesc) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BindGroupDesc
impl StructuralPartialEq for BindGroupDesc