pub struct GpuBindGroupLayoutHandle(/* private fields */);Trait Implementations
Sourceimpl Clone for GpuBindGroupLayoutHandle
impl Clone for GpuBindGroupLayoutHandle
Sourcefn clone(&self) -> GpuBindGroupLayoutHandle
fn clone(&self) -> GpuBindGroupLayoutHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for GpuBindGroupLayoutHandle
Sourceimpl Debug for GpuBindGroupLayoutHandle
impl Debug for GpuBindGroupLayoutHandle
Sourceimpl Default for GpuBindGroupLayoutHandle
impl Default for GpuBindGroupLayoutHandle
Sourcefn default() -> GpuBindGroupLayoutHandle
fn default() -> GpuBindGroupLayoutHandle
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GpuBindGroupLayoutHandle
impl<'de> Deserialize<'de> for GpuBindGroupLayoutHandle
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GpuBindGroupLayoutHandle
Sourceimpl From<KeyData> for GpuBindGroupLayoutHandle
impl From<KeyData> for GpuBindGroupLayoutHandle
Sourceimpl Hash for GpuBindGroupLayoutHandle
impl Hash for GpuBindGroupLayoutHandle
Sourceimpl Key for GpuBindGroupLayoutHandle
impl Key for GpuBindGroupLayoutHandle
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for GpuBindGroupLayoutHandle
impl Ord for GpuBindGroupLayoutHandle
Sourcefn cmp(&self, other: &GpuBindGroupLayoutHandle) -> Ordering
fn cmp(&self, other: &GpuBindGroupLayoutHandle) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpuBindGroupLayoutHandle
impl PartialEq for GpuBindGroupLayoutHandle
Sourcefn eq(&self, other: &GpuBindGroupLayoutHandle) -> bool
fn eq(&self, other: &GpuBindGroupLayoutHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpuBindGroupLayoutHandle
impl PartialOrd for GpuBindGroupLayoutHandle
Sourceimpl Serialize for GpuBindGroupLayoutHandle
impl Serialize for GpuBindGroupLayoutHandle
impl StructuralPartialEq for GpuBindGroupLayoutHandle