pub struct ShaderModuleDesc {
pub label: Label,
pub source: PathBuf,
pub extra_workaround_replacements: Vec<(String, String)>,
}Fields
label: LabelDebug label of the shader. This will show up in graphics debuggers for easy identification.
source: PathBufPath to the source code of this shader module.
extra_workaround_replacements: Vec<(String, String)>Additional text replacement workarounds that may be added on top of globally known workarounds.