pub struct ViewPickingConfiguration {
pub picking_rect: RectInt,
pub readback_identifier: GpuReadbackIdentifier,
pub show_debug_view: bool,
}Expand description
Configures the readback of a rectangle from the picking layer.
The picking result will still be valid if the rectangle is partially or fully outside of bounds. Areas that are not overlapping with the primary target will be filled as-if the view’s target was bigger, i.e. all values are valid picking IDs, it is up to the user to discard anything that is out of bounds.
Data from the picking rect needs to be retrieved via crate::PickingLayerProcessor::readback_result.
To do so, you need to pass the exact same identifier and type of user data.
Received data that isn’t retrieved for more than a frame will be automatically discarded.
Fields
picking_rect: RectIntThe rectangle to read back from the picking layer.
readback_identifier: GpuReadbackIdentifierIdentifier to be passed to the readback result.
show_debug_view: boolWhether to draw a debug view of the picking layer when compositing the final view.